==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/ResultSetException.hpp <==
#ifndef _COM_SUN_STAR_UCB_RESULTSETEXCEPTION_HPP_
#define _COM_SUN_STAR_UCB_RESULTSETEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_RESULTSETEXCEPTION_HDL_
#include "com/sun/star/ucb/ResultSetException.hdl"
#endif

#ifndef _COM_SUN_STAR_SDBC_SQLEXCEPTION_HPP_
#include "com/sun/star/sdbc/SQLException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline ResultSetException::ResultSetException() SAL_THROW( () )
    : ::com::sun::star::sdbc::SQLException()
{ }

inline ResultSetException::ResultSetException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::rtl::OUString& SQLState_, const ::sal_Int32& ErrorCode_, const ::com::sun::star::uno::Any& NextException_) SAL_THROW( () )
    : ::com::sun::star::sdbc::SQLException(Message_, Context_, SQLState_, ErrorCode_, NextException_)
{ }

ResultSetException::ResultSetException(ResultSetException const & the_other): ::com::sun::star::sdbc::SQLException(the_other) {}

ResultSetException::~ResultSetException() {}

ResultSetException & ResultSetException::operator =(ResultSetException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::sdbc::SQLException::operator =(the_other);
    return *this;
}

} } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::ucb::ResultSetException* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.ucb.ResultSetException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_UCB_RESULTSETEXCEPTION_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/ResultSetException.hpp <==
#ifndef _COM_SUN_STAR_UCB_RESULTSETEXCEPTION_HPP_
#define _COM_SUN_STAR_UCB_RESULTSETEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_RESULTSETEXCEPTION_HDL_
#include "com/sun/star/ucb/ResultSetException.hdl"
#endif

#ifndef _COM_SUN_STAR_SDBC_SQLEXCEPTION_HPP_
#include "com/sun/star/sdbc/SQLException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline ResultSetException::ResultSetException() SAL_THROW( () )
    : ::com::sun::star::sdbc::SQLException()
{ }

inline ResultSetException::ResultSetException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::rtl::OUString& SQLState_, const ::sal_Int32& ErrorCode_, const ::com::sun::star::uno::Any& NextException_) SAL_THROW( () )
    : ::com::sun::star::sdbc::SQLException(Message_, Context_, SQLState_, ErrorCode_, NextException_)
{ }

ResultSetException::ResultSetException(ResultSetException const & the_other): ::com::sun::star::sdbc::SQLException(the_other) {}

ResultSetException::~ResultSetException() {}

ResultSetException & ResultSetException::operator =(ResultSetException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::sdbc::SQLException::operator =(the_other);
    return *this;
}

} } } }

namespace com { namespace sun { namespace star { namespace ucb {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::ucb::ResultSetException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.ucb.ResultSetException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::ucb::ResultSetException const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::ucb::ResultSetException >::get();
}

#endif // _COM_SUN_STAR_UCB_RESULTSETEXCEPTION_HPP_
